@@ -3,9 +3,7 @@ import { Direction } from "./kore/Direction";
 import { ShipyardAction } from "./kore/ShipyardAction";
 import { KoreIO } from "./kore/KoreIO";
 
-const io = new KoreIO();
-// agent.run takes care of running your code per tick
-io.run((board: Board): Board => {
+export const tick = async (board: Board): Promise<Board> => {
     const me = board.currentPlayer;
     const turn = board.step;
     const spawnCost = board.configuration.spawnCost;
@@ -29,6 +27,8 @@ io.run((board: Board): Board => {
 
     // nextActions will be pulled off of your shipyards
     return board;
-});
-
+}
 
+// agent.run takes care of running your code per tick
+const io = new KoreIO();
+io.run(tick);
